@@ -141,6 +141,9 @@ class Tredis_subscribe(threading.Thread):
 
 
 class Tredis:
+    default_port = 6379
+    default_db = 0
+
     def __init__(self,
                  server='localhost',
                  port=6379,
